@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef enum {
@@ -12,6 +9,8 @@ typedef enum {
 
 typedef struct _E_Event_Bg_Update E_Event_Bg_Update;
 
+typedef struct _E_Bg_Image_Import_Handle E_Bg_Image_Import_Handle;
+
 #else
 #ifndef E_BG_H
 #define E_BG_H
@@ -33,12 +32,15 @@ EAPI const E_Config_Desktop_Background *e_bg_config_get(int container_num, int z
 EAPI const char *e_bg_file_get(int container_num, int zone_num,  int desk_x, int desk_y);
 EAPI void e_bg_zone_update(E_Zone *zone, E_Bg_Transition transition);
 EAPI void e_bg_zone_slide(E_Zone *zone, int prev_x, int prev_y);
-EAPI void e_bg_add(int container, int zone, int desk_x, int desk_y, char *file);
+EAPI void e_bg_add(int container, int zone, int desk_x, int desk_y, const char *file);
 EAPI void e_bg_del(int container, int zone, int desk_x, int desk_y);
-EAPI void e_bg_default_set(char *file);
+EAPI void e_bg_default_set(const char *file);
 EAPI void e_bg_update(void);
 EAPI void e_bg_handler_set(Evas_Object *obj, const char *path, void *data);
 EAPI int  e_bg_handler_test(Evas_Object *obj, const char *path, void *data);
 
+EAPI E_Bg_Image_Import_Handle *e_bg_image_import_new(const char *image_file, void (*cb)(void *data, const char *edje_file), const void *data);
+EAPI void                      e_bg_image_import_cancel(E_Bg_Image_Import_Handle *handle);
+
 #endif
 #endif
