@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 #define E_CONFIG_LIMIT(v, min, max) {if (v > max) v = max; else if (v < min) v = min;}
@@ -13,6 +10,7 @@ typedef struct _E_Config_Binding_Key        E_Config_Binding_Key;
 typedef struct _E_Config_Binding_Edge       E_Config_Binding_Edge;
 typedef struct _E_Config_Binding_Signal     E_Config_Binding_Signal;
 typedef struct _E_Config_Binding_Wheel      E_Config_Binding_Wheel;
+typedef struct _E_Config_Binding_Acpi       E_Config_Binding_Acpi;
 typedef struct _E_Config_Desktop_Background E_Config_Desktop_Background;
 typedef struct _E_Config_Desktop_Name       E_Config_Desktop_Name;
 typedef struct _E_Config_Gadcon             E_Config_Gadcon;
@@ -21,21 +19,20 @@ typedef struct _E_Config_Shelf              E_Config_Shelf;
 typedef struct _E_Config_Shelf_Desk         E_Config_Shelf_Desk;
 typedef struct _E_Config_Mime_Icon          E_Config_Mime_Icon;
 typedef struct _E_Config_Syscon_Action      E_Config_Syscon_Action;
-
 typedef struct _E_Event_Config_Icon_Theme   E_Event_Config_Icon_Theme;
 
 #else
 #ifndef E_CONFIG_H
 #define E_CONFIG_H
 
-/* increment this whenever we change config enough that you need new 
+/* increment this whenever we change config enough that you need new
  * defaults for e to work.
  */
 #define E_CONFIG_FILE_EPOCH      0x0001
 /* increment this whenever a new set of config values are added but the users
  * config doesn't need to be wiped - simply new values need to be put in
  */
-#define E_CONFIG_FILE_GENERATION 0x0133
+#define E_CONFIG_FILE_GENERATION 0x0141
 #define E_CONFIG_FILE_VERSION    ((E_CONFIG_FILE_EPOCH << 16) | E_CONFIG_FILE_GENERATION)
 
 #define E_EVAS_ENGINE_DEFAULT         0
@@ -104,6 +101,7 @@ struct _E_Config
    Eina_List  *edge_bindings; // GUI
    Eina_List  *signal_bindings;
    Eina_List  *wheel_bindings; // GUI
+   Eina_List  *acpi_bindings; // GUI
    Eina_List  *path_append_data; // GUI
    Eina_List  *path_append_images; // GUI
    Eina_List  *path_append_fonts; // GUI
@@ -126,6 +124,8 @@ struct _E_Config
    int         desk_resist; // GUI
    int         window_resist; // GUI
    int         gadget_resist; // GUI
+   int         geometry_auto_move; // GUI
+   int         geometry_auto_resize_limit; // GUI
    int         winlist_warp_while_selecting; // GUI
    int         winlist_warp_at_end; // GUI
    double      winlist_warp_speed; // GUI
@@ -189,25 +189,12 @@ struct _E_Config
    int         menu_favorites_show; // GUI
    int         menu_apps_show; // GUI
    int         fullscreen_policy; // GUI
-   int         exebuf_max_exe_list; // GUI
-   int         exebuf_max_eap_list; // GUI
-   int         exebuf_max_hist_list; // GUI
-   int         exebuf_scroll_animate; // GUI
-   double      exebuf_scroll_speed; // GUI
-   double      exebuf_pos_align_x; // GUI
-   double      exebuf_pos_align_y; // GUI
-   double      exebuf_pos_size_w; // GUI
-   double      exebuf_pos_size_h; // GUI
-   int         exebuf_pos_min_w; // GUI
-   int         exebuf_pos_min_h; // GUI
-   int         exebuf_pos_max_w; // GUI
-   int         exebuf_pos_max_h; // GUI
    const char *exebuf_term_cmd; // GUI
    Eina_List  *color_classes; // GUI
    int         use_app_icon; // GUI
    int         cnfmdlg_disabled; // GUI
    int         cfgdlg_auto_apply; // GUI
-   int         cfgdlg_default_mode; // GUI   
+   int         cfgdlg_default_mode; // GUI
    Eina_List  *gadcons; // GUI
    Eina_List  *shelves; // GUI
    int         font_hinting; // GUI
@@ -217,6 +204,7 @@ struct _E_Config
    int         desklock_auth_method; // GUI
    int         desklock_login_box_zone; // GUI
    int         desklock_start_locked; // GUI
+   int         desklock_on_suspend; // GUI
    int         desklock_autolock_screensaver; // GUI
    double      desklock_post_screensaver_time; // GUI
    int         desklock_autolock_idle; // GUI
@@ -233,7 +221,7 @@ struct _E_Config
    int         screensaver_expose; // GUI
    Eina_Bool   screensaver_ask_presentation; // GUI
    double      screensaver_ask_presentation_timeout; // GUI
-  
+
    int         dpms_enable; // GUI
    int         dpms_standby_enable; // GUI
    int         dpms_standby_timeout; // GUI
@@ -255,12 +243,9 @@ struct _E_Config
    int         mouse_accel_numerator; // GUI
    int         mouse_accel_denominator; // GUI
    int         mouse_accel_threshold; // GUI
-   
-   int         display_res_restore; // GUI
-   int         display_res_width; // GUI
-   int         display_res_height; // GUI
-   int         display_res_hz; // GUI
-   int         display_res_rotation; // GUI
+
+   Eina_List   *screen_info; // GUI
+
    int         border_raise_on_mouse_action; // GUI
    int         border_raise_on_focus; // GUI
    int         desk_flip_wrap; // GUI
@@ -268,14 +253,14 @@ struct _E_Config
 
    const char *icon_theme; // GUI
    Eina_Bool   icon_theme_overrides; // GUI
-   
+
    int         desk_flip_animate_mode; // GUI
    int         desk_flip_animate_interpolation; // GUI
    double      desk_flip_animate_time; // GUI
    Eina_Bool   desk_flip_pan_bg;
    double      desk_flip_pan_x_axis_factor;
    double      desk_flip_pan_y_axis_factor;
-   
+
    const char *wallpaper_import_last_dev; // INTERNAL
    const char *wallpaper_import_last_path; // INTERNAL
 
@@ -287,23 +272,23 @@ struct _E_Config
    int wallpaper_grad_c2_b; // INTERNAL
 
    const char *theme_default_border_style; // GUI
-   
+
    Eina_List *mime_icons; // GUI
    int desk_auto_switch; // GUI;
 
    int thumb_nice;
-   
+
    int ping_clients_interval;
    int cache_flush_poll_interval; // GUI
-   
+
    int thumbscroll_enable; // GUI
    int thumbscroll_threshhold; // GUI
    double thumbscroll_momentum_threshhold; // GUI
    double thumbscroll_friction; // GUI
 
-   int hal_desktop;
-   int hal_auto_mount;
-   int hal_auto_open;
+   int device_desktop;
+   int device_auto_mount;
+   int device_auto_open;
 
    struct {
       double timeout;
@@ -316,7 +301,7 @@ struct _E_Config
 	 unsigned char dy;
       } resize;
    } border_keyboard;
-   
+
    struct {
       double min; // GUI
       double max; // GUI
@@ -328,11 +313,11 @@ struct _E_Config
 
    unsigned char show_cursor; // GUI
    unsigned char idle_cursor; // GUI
-   
+
    const char *default_system_menu;
 
    unsigned char cfgdlg_normal_wins; // GUI
-   
+
    struct {
       struct {
          int icon_size;
@@ -346,6 +331,12 @@ struct _E_Config
       Eina_Bool presentation;
       Eina_Bool offline;
    } mode;
+
+   struct {
+      double    expire_timeout;
+      Eina_Bool show_run_dialog;
+      Eina_Bool show_exit_dialog;
+   } exec;
 };
 
 struct _E_Config_Syscon_Action
@@ -424,6 +415,12 @@ struct _E_Config_Binding_Wheel
    const char    *params;
 };
 
+struct _E_Config_Binding_Acpi
+{
+   int context, type, status;
+   const char *action, *params;
+};
+
 struct _E_Config_Desktop_Background
 {
    int            container;
@@ -446,6 +443,7 @@ struct _E_Config_Gadcon
 {
    const char *name;
    int         id;
+   int         zone;
    Eina_List  *clients;
 };
 
@@ -507,7 +505,7 @@ EAPI int        e_config_init(void);
 EAPI int        e_config_shutdown(void);
 
 EAPI void       e_config_load(void);
-    
+
 EAPI int        e_config_save(void);
 EAPI void       e_config_save_flush(void);
 EAPI void       e_config_save_queue(void);
@@ -523,7 +521,7 @@ EAPI Eina_List *e_config_engine_list(void);
 
 EAPI void       e_config_save_block_set(int block);
 EAPI int        e_config_save_block_get(void);
-    
+
 EAPI void      *e_config_domain_load(const char *domain, E_Config_DD *edd);
 EAPI void      *e_config_domain_system_load(const char *domain, E_Config_DD *edd);
 EAPI int        e_config_profile_save(void);
@@ -534,6 +532,7 @@ EAPI E_Config_Binding_Key    *e_config_binding_key_match(E_Config_Binding_Key *e
 EAPI E_Config_Binding_Edge   *e_config_binding_edge_match(E_Config_Binding_Edge *eb_in);
 EAPI E_Config_Binding_Signal *e_config_binding_signal_match(E_Config_Binding_Signal *eb_in);
 EAPI E_Config_Binding_Wheel  *e_config_binding_wheel_match(E_Config_Binding_Wheel *eb_in);
+EAPI E_Config_Binding_Acpi   *e_config_binding_acpi_match(E_Config_Binding_Acpi *eb_in);
 EAPI void                     e_config_mode_changed(void);
 
 extern EAPI E_Config *e_config;
