@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Exec_Instance E_Exec_Instance;
@@ -12,6 +9,7 @@ typedef struct _E_Exec_Instance E_Exec_Instance;
 struct _E_Exec_Instance
 {
    Efreet_Desktop *desktop;
+   const char     *key;
    Ecore_Exe      *exe;
    int             startup_id;
    double          launch_time;
