@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 #else
@@ -12,7 +9,7 @@ EAPI int e_filereg_shutdown(void);
 
 EAPI int e_filereg_register(const char * path);
 EAPI void e_filereg_deregister(const char * path);
-EAPI Evas_Bool e_filereg_file_protected(const char * path);
+EAPI Eina_Bool e_filereg_file_protected(const char * path);
 
 #endif
 #endif
