@@ -1,11 +1,10 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 #ifdef USE_IPC
-#include      "e_ipc_handlers_list.h"
 
+#define E_IPC_OP_EXEC_ACTION 386
+#define E_IPC_OP_EXEC_ACTION_REPLY 387
+  
 typedef enum _E_Ipc_Domain
 {
    E_IPC_DOMAIN_NONE,
