@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Order        E_Order;
@@ -18,6 +15,7 @@ struct _E_Order
    const char         *path;
    Eina_List          *desktops; /* A list of Efreet_Desktop files this .order contains */
    Ecore_File_Monitor *monitor; /* Check for changes int the .order file */
+   Ecore_Timer        *delay;
 
    struct {
 	void (*update)(void *data, E_Order *eo);
