@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Sys_Con_Action E_Sys_Con_Action;
@@ -27,7 +24,7 @@ struct _E_Sys_Con_Action
    const char *button_name;
    void (*func) (void *data);
    const void *data;
-   Evas_Bool disabled : 1;
+   Eina_Bool disabled : 1;
 };
 
 #else
