@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 #else
 #ifndef E_WIDGET_TOOLBAR_H
@@ -11,8 +8,10 @@ EAPI void e_widget_toolbar_item_append(Evas_Object *obj, Evas_Object *icon, cons
 EAPI void e_widget_toolbar_item_remove(Evas_Object *obj, int num);
 EAPI void e_widget_toolbar_item_select(Evas_Object *obj, int num);
 EAPI void e_widget_toolbar_item_label_set(Evas_Object *obj, int num, const char *label);
-EAPI void e_widget_toolbar_scrollable_set(Evas_Object *obj, Evas_Bool scrollable);
-EAPI void e_widget_toolbar_focus_steal_set(Evas_Object *obj, Evas_Bool steal);
+EAPI void e_widget_toolbar_scrollable_set(Evas_Object *obj, Eina_Bool scrollable);
+EAPI void e_widget_toolbar_focus_steal_set(Evas_Object *obj, Eina_Bool steal);
+EAPI void e_widget_toolbar_clear(Evas_Object *obj);
+EAPI int e_widget_toolbar_item_selected_get(Evas_Object *obj);
 
 #endif
 #endif
